@@ -41,12 +41,12 @@ command, for Go.
 		List       bool             `help:"List lexers, styles and formatters."`
 		Unbuffered bool             `help:"Do not buffer output."`
 		Trace      bool             `help:"Trace lexer states as they are traversed."`
-		Check      bool             `help:"Do not format, check for tokenization errors instead."`
+		Check      bool             `help:"Do not format, check for tokenisation errors instead."`
 		Filename   string           `help:"Filename to use for selecting a lexer when reading from stdin."`
 
-		Lexer     string `help:"Lexer to use when formatting." placeholder:"autodetect" short:"l"`
-		Style     string `help:"Style to use for formatting." default:"swapoff" short:"s"`
-		Formatter string `help:"Formatter to use." default:"terminal" short:"f"`
+		Lexer     string `help:"Lexer to use when formatting." default:"autodetect" short:"l" enum:"${lexers}"`
+		Style     string `help:"Style to use for formatting." default:"swapoff" short:"s" enum:"${styles}"`
+		Formatter string `help:"Formatter to use." default:"terminal" short:"f" enum:"${formatters}"`
 
 		JSON bool `help:"Output JSON representation of tokens."`
 
@@ -64,6 +64,8 @@ command, for Go.
 		HTMLBaseLine              int    `help:"Base line number." default:"1"`
 		HTMLPreventSurroundingPre bool   `help:"Prevent the surrounding pre tag."`
 
+		SVG bool `help:"Output SVG representation of tokens."`
+
 		Files []string `arg:"" optional:"" help:"Files to highlight." type:"existingfile"`
 	}
 )
@@ -79,7 +81,10 @@ func (n *nopFlushableWriter) Flush() error { return nil }
 
 func main() {
 	ctx := kong.Parse(&cli, kong.Description(description), kong.Vars{
-		"version": fmt.Sprintf("%s-%s-%s", version, commit, date),
+		"version":    fmt.Sprintf("%s-%s-%s", version, commit, date),
+		"lexers":     "autodetect," + strings.Join(lexers.Names(true), ","),
+		"styles":     strings.Join(styles.Names(), ","),
+		"formatters": strings.Join(formatters.Names(), ","),
 	})
 	if cli.List {
 		listAll()
@@ -112,12 +117,13 @@ func main() {
 	}
 	defer w.Flush() // nolint: errcheck
 
-	if cli.JSON {
+	switch {
+	case cli.JSON:
 		cli.Formatter = "json"
-	}
-
-	if cli.HTML {
+	case cli.HTML:
 		cli.Formatter = "html"
+	case cli.SVG:
+		cli.Formatter = "svg"
 	}
 
 	// Retrieve user-specified style, clone it, and add some overrides.
@@ -133,54 +139,14 @@ func main() {
 
 	// Dump styles.
 	if cli.HTMLStyles {
-		formatter := html.New(html.WithClasses())
+		formatter := html.New(html.WithClasses(true))
 		err = formatter.WriteCSS(w, style)
 		ctx.FatalIfErrorf(err)
 		return
 	}
 
 	if cli.Formatter == "html" {
-		options := []html.Option{
-			html.TabWidth(cli.HTMLTabWidth),
-			html.BaseLineNumber(cli.HTMLBaseLine),
-		}
-		if cli.HTMLPrefix != "" {
-			options = append(options, html.ClassPrefix(cli.HTMLPrefix))
-		}
-		if !cli.HTMLInlineStyles {
-			options = append(options, html.WithClasses())
-		}
-		if !cli.HTMLOnly {
-			options = append(options, html.Standalone())
-		}
-		if cli.HTMLLines {
-			options = append(options, html.WithLineNumbers())
-		}
-		if cli.HTMLLinesTable {
-			options = append(options, html.LineNumbersInTable())
-		}
-		if cli.HTMLPreventSurroundingPre {
-			options = append(options, html.PreventSurroundingPre())
-		}
-		if len(cli.HTMLHighlight) > 0 {
-			ranges := [][2]int{}
-			for _, span := range strings.Split(cli.HTMLHighlight, ",") {
-				parts := strings.Split(span, ":")
-				if len(parts) > 2 {
-					ctx.Fatalf("range should be N[:M], not %q", span)
-				}
-				start, err := strconv.ParseInt(parts[0], 10, 64)
-				ctx.FatalIfErrorf(err, "min value of range should be integer not %q", parts[0])
-				end := start
-				if len(parts) == 2 {
-					end, err = strconv.ParseInt(parts[1], 10, 64)
-					ctx.FatalIfErrorf(err, "max value of range should be integer not %q", parts[1])
-				}
-				ranges = append(ranges, [2]int{int(start), int(end)})
-			}
-			options = append(options, html.HighlightLines(ranges))
-		}
-		formatters.Register("html", html.New(options...))
+		configureHTMLFormatter(ctx)
 	}
 	if len(cli.Files) == 0 {
 		contents, err := ioutil.ReadAll(os.Stdin)
@@ -199,6 +165,38 @@ func main() {
 	}
 }
 
+func configureHTMLFormatter(ctx *kong.Context) {
+	options := []html.Option{
+		html.TabWidth(cli.HTMLTabWidth),
+		html.BaseLineNumber(cli.HTMLBaseLine),
+		html.ClassPrefix(cli.HTMLPrefix),
+		html.WithClasses(!cli.HTMLInlineStyles),
+		html.Standalone(!cli.HTMLOnly),
+		html.WithLineNumbers(cli.HTMLLines),
+		html.LineNumbersInTable(cli.HTMLLinesTable),
+		html.PreventSurroundingPre(cli.HTMLPreventSurroundingPre),
+	}
+	if len(cli.HTMLHighlight) > 0 {
+		ranges := [][2]int{}
+		for _, span := range strings.Split(cli.HTMLHighlight, ",") {
+			parts := strings.Split(span, ":")
+			if len(parts) > 2 {
+				ctx.Fatalf("range should be N[:M], not %q", span)
+			}
+			start, err := strconv.ParseInt(parts[0], 10, 64)
+			ctx.FatalIfErrorf(err, "min value of range should be integer not %q", parts[0])
+			end := start
+			if len(parts) == 2 {
+				end, err = strconv.ParseInt(parts[1], 10, 64)
+				ctx.FatalIfErrorf(err, "max value of range should be integer not %q", parts[1])
+			}
+			ranges = append(ranges, [2]int{int(start), int(end)})
+		}
+		options = append(options, html.HighlightLines(ranges))
+	}
+	formatters.Register("html", html.New(options...))
+}
+
 func listAll() {
 	fmt.Println("lexers:")
 	sort.Sort(lexers.Registry.Lexers)
@@ -246,7 +244,7 @@ func lex(ctx *kong.Context, path string, contents string) chroma.Iterator {
 }
 
 func selexer(path, contents string) (lexer chroma.Lexer) {
-	if cli.Lexer != "" {
+	if cli.Lexer != "autodetect" {
 		return lexers.Get(cli.Lexer)
 	}
 	if path != "" {
